# This makes the directory a package. 
# You can use it to define what gets exposed when someone imports the package.
# src/your_package_name/__init__.py

from duderanch_package.firstModule import hello

__all__ = ["hello"]

#This allows people to do:
# from your_package_name import hello

# print(hello())         # "Hello, World!"
# print(hello("Alice"))  # "Hello, Alice!"



# tests/test_your_module.py

import unittest
from duderanch_package import hello

class TestHelloFunction(unittest.TestCase):
    def test_hello_default(self):
        self.assertEqual(hello(), "Hello, World!")

    def test_hello_custom_name(self):
        self.assertEqual(hello("Alice"), "Hello, Alice!")

if __name__ == "__main__":
    unittest.main()
